clear all; close all; clc

%figure
%hold on

filename1 = 'Baseline5S.xlsx';
filename2 = 'BVID5S.xlsx';
sgtitle([sprintf(filename1),' vs. ',sprintf(filename2)])
%sgt.FontSize = 24;

if (regexp(filename1,'5S'))
    pos = 8;
    x = [65;98;84;35;36;12;11]; y=[21;47;20;7;41;40;12];
else
    pos = 6;
    x = [65;84;38;24;10]; y=[21;20;41;10;33]; 
end

f = 10;
series_1 = xlsread(filename1); series_1 = series_1(2:f:end,:);
series_2 = xlsread(filename2); series_2 = series_2(2:f:end,:);

x1 = mat2gray(series_1(:,4));
x2 = mat2gray(series_2(:,3));

fs = f*1e6./-(series_1(1,1) - series_1(2,1));
signal = ([x1 x2]);
hpass = 50e3; %Lowest freq = 50 kHz
signal = mat2gray(highpass(signal,hpass,fs));
x1 = signal(:,1); env_x1 = envelope(x1);
x2 = signal(:,2); env_x2 = envelope(x2);

baseline_cc = 0; % Only for Baseline to Baseline comparison at 84|20 cm
if baseline_cc == 1
start = 392;
finish = length(x1);
for b = start:finish % Loop between start to finish period
    corr_coeff_signal = corrcoef(x1(start-1:b),x2(start-1:b)); %Calculate CorrCoeff
    CC_signal(b,:) = [b-start+1 corr_coeff_signal(1,2)]; % Save CorrCoeff to Matrix CC
    corr_coeff_env = corrcoef(env_x1(start-1:b),env_x2(start-1:b));%Calculate CorrCoeff
    CC_env(b,:) = [b-start+1 corr_coeff_env(1,2)]; % Save CorrCoeff to Matrix CC
end

% Normalize CC Matrix
CC_signal(:,2) = mat2gray(CC_signal(:,2)); CC_env(:,2) = mat2gray(CC_env(:,2));
t1 = series_1(:,1); 

%subplot(2,1,1)
line_width = 1;
plot(t1(start:finish),x1(start:finish),'-','LineWidth',line_width)
hold on
plot(t1(start:finish),x2(start:finish),'-','LineWidth',line_width)
hold on
plot(t1(start:finish),CC_signal(start:finish,2),'o','LineWidth',line_width)
hold on
plot(t1(start:finish),env_x1(start:finish),'*','LineWidth',line_width+2)
hold on
plot(t1(start:finish),env_x2(start:finish),'*','LineWidth',line_width+2)
hold on
plot(t1(start:finish),CC_env(start:finish,2),'o','LineWidth',line_width)

fig = gcf; fig.Color = [1 1 1]; fig.Position = [0, 100, 1280, 740];
xlim([0 300])
ylim([0 1])
grid on
grid(gca,'minor')
n = 10;
set(gca,'fontsize',n)
legend('Case-1A','Case-1B','CC_1_-_A_1_-_B','Env-Case-1A','Env-Case-1B','CC_E_n_v','FontSize',n);
xlabel('Time [s]','FontSize',n) ; ylabel('Normalized Amplitude','FontSize',n);
end

%Note: i starts from 3, because COL1 = Time-axis, COL2 = ACT
for i = 3:pos
% Read data
f = 10; %Compression rate
series_1 = xlsread(filename1); series_1 = series_1(2:f:end,:);
series_2 = xlsread(filename2); series_2 = series_2(2:f:end,:);
t1 = series_1(:,1); t2 = series_2(:,1);
fs = f*1e6./-(series_1(1,1) - series_1(2,1));

t_sum = sum(t1 - t2);
if t_sum == 0
    disp('Time axis OK')
end

% High-pass Filter
signal = ([series_1(:,i) series_2(:,i)]);
hpass = 50e3; %Lowest freq = 50 kHz
signal = highpass(signal,hpass,fs);
signal_diff = signal(:,1) - signal(:,2);

% Normalization
signal_norm = mat2gray(signal);
signal_diff = mat2gray(signal_diff);

% Windowing from start to finish
start = 392; % Time begins at time steps 392 due to pre-capture offset
finish = 3900; % Consider 3900 time step (390 s)
signal_env = envelope(signal_norm(start:finish,:));
diff_env = envelope(signal_diff);
env_norm =  mat2gray(signal_env);

%instfreq(signal_norm(:,1)-signal_norm(:,2),fs);
%C = unwrap(angle(signal));
%plot(C)

for b = start:finish % Loop between start to finish period
    corr_coeff_signal = corrcoef(signal_norm(start-1:b,1),signal_norm(start-1:b,2)); %Calculate CorrCoeff
    CC_signal(b-start+1,:) = [b corr_coeff_signal(1,2)]; % Save CorrCoeff to Matrix CC
end

CC_signal(:,2) = mat2gray(CC_signal(:,2)); % Normalize saved CorrCoeff because signal from -1 to +1

for b = 2:(finish-start) % Loop between start to finish period
    corr_coeff_env = corrcoef(env_norm(1:b,1),env_norm(1:b,2)); %Calculate CorrCoeff
    CC_env(b-1,:) = [b corr_coeff_env(1,2)]; % Save CorrCoeff to Matrix CC
end

subplot(2,(pos-2)/2,i-2)
line_width = 1;
plot(t1(start:finish),signal_norm(start:finish,:),'-','LineWidth',line_width)
hold on
plot(t1(start:finish),signal_env,'--','LineWidth',line_width+2)
hold on
plot(t1(start:finish),CC_signal(:,2),'o','LineWidth',line_width)
hold on
plot(t1(start:finish-2),CC_env(:,2),'o','LineWidth',line_width)
hold on

ax = gca;
outerpos = ax.OuterPosition;
ti = ax.TightInset; 
left = outerpos(1) + ti(1);
bottom = outerpos(2) + ti(2);
ax_width = 1.12.*(outerpos(3) - ti(1) - ti(3));
ax_height = 0.98.*(outerpos(4) - ti(2) - ti(4));
ax.Position = [left-0.03 bottom-0.03 ax_width ax_height];

fig = gcf; fig.Color = [1 1 1]; fig.Position = [0, 100, 1280, 740];
xlim([0 300])
ylim([0 1])
grid on
grid(gca,'minor')
n = 12;
set(gca,'fontsize',n)
legend('Baseline','Damaged','EnvBaseline','EnvDamage','CC_S_i_g_n_a_l','CC_E_n_v','FontSize',n);
xlabel('Time [s]','FontSize',n) ; ylabel('Normalized Amplitude','FontSize',n);
title(['Sensor Location: ',num2str(x(i-1)),'|',num2str(y(i-1)),'cm'])

end